@@ -11,6 +11,7 @@ from mdformat.renderer._util import (
     find_opening_token,
     is_text_inside_autolink,
     longest_consecutive_sequence,
+    maybe_add_link_brackets,
 )
 
 LOGGER = logging.getLogger(__name__)
@@ -44,15 +45,17 @@ def link_close(
         return f"][{open_tkn.meta['label'].lower()}]"
     attrs = dict(open_tkn.attrs)
     uri = attrs["href"]
+    uri = maybe_add_link_brackets(uri)
     title = attrs.get("title")
     if title is None:
-        return f"](<{uri}>)"
+        return f"]({uri})"
     title = title.replace('"', '\\"')
-    return f'](<{uri}> "{title}")'
+    return f']({uri} "{title}")'
 
 
 def hr(tokens: Sequence[Token], idx: int, options: Mapping[str, Any], env: dict) -> str:
-    return "___" + MARKERS.BLOCK_SEPARATOR
+    thematic_break_width = 70
+    return "_" * thematic_break_width + MARKERS.BLOCK_SEPARATOR
 
 
 def image(
@@ -78,10 +81,11 @@ def image(
 
     uri = token.attrGet("src")
     assert uri is not None
+    uri = maybe_add_link_brackets(uri)
     title = token.attrGet("title")
     if title is not None:
-        return f'![{label}](<{uri}> "{title}")'
-    return f"![{label}](<{uri}>)"
+        return f'![{label}]({uri} "{title}")'
+    return f"![{label}]({uri})"
 
 
 def code_inline(
@@ -167,10 +171,8 @@ def text(
 ) -> str:
     """Process a text token.
 
-    Text should always be a child of an inline token enclosed by a
-      - heading
-      - paragraph
-      - autolink (any link?)
+    Text should always be a child of an inline token. An inline token
+    should always be enclosed by a heading or a paragraph.
     """
     text = tokens[idx].content
     if is_text_inside_autolink(tokens, idx):
@@ -195,14 +197,6 @@ def text(
         start = char_ref.start() + char_refs_found
         text = text[:start] + "\\" + text[start:]
 
-    # Replace line starting tabs with numeric decimal representation.
-    # A normal tab character would start a code block.
-    lines = text.split("\n")
-    starting_tabs_replaced = (
-        "&#9;" + line[1:] if line.startswith("\t") else line for line in lines
-    )
-    text = "\n".join(starting_tabs_replaced)
-
     # Replace no-break space with its decimal representation
     text = text.replace(chr(160), "&#160;")
 
